@@ -50,7 +50,7 @@ class API:
         options = webdriver.ChromeOptions()
         options.add_argument("--ignore-certificate-errors")
         options.add_argument("--incognito")
-        # options.add_argument("--headless")
+        options.add_argument("--headless")
         driver = webdriver.Chrome(WEB_DRIVER_PATH, options=options)
 
         return driver
